Example of connection and energy GMM obtained from functions
get_connection_models and get_energy_models respectively.
They have been created using an Open source data set of EV charging sessions
provided by ACN.
More information about the development of the model in the evprof website:
https://mcanigueral.github.io/evprof/articles/california.html
california_GMMlist
Tibble with the parameters of the bi-variate
(connection start time and connection duration) GMM from the working/weekend days
sessions of the California data set obtained from get_connection_models
Tibble with the parameters of the uni-variate
(energy) GMM from the working/weekend days sessions of the California data set
obtained from get_energy_models