california_ev_sessions_profiles: Clustered EV charging sessions example

california_ev_sessions_profilesR Documentation

Clustered EV charging sessions example

Description

Example of an charging sessions data set that has been clustered by evprof functions. (see this article).

Usage

california_ev_sessions_profiles

Format

california_ev_sessions_profiles

A tibble object with standard variable names defined by evprof

https://ev.caltech.edu/dataset


evprof documentation built on Dec. 24, 2025, 1:06 a.m.