convert_time_dt_to_plot_num: Convert datetime values to sorted numeric values considering...

View source: R/exploration.R

convert_time_dt_to_plot_numR Documentation

Convert datetime values to sorted numeric values considering a start time

Description

Convert datetime values to sorted numeric values considering a start time

Usage

convert_time_dt_to_plot_num(time_dt, start = getOption("evprof.start.hour"))

Arguments

time_dt

Datetime value

start

Start hour (int)


evprof documentation built on Dec. 24, 2025, 1:06 a.m.