Learn R Programming

evprof (version 1.1.2)

get_daily_n_sessions: Get daily number of sessions given a range of years, months and weekdays

Description

Get daily number of sessions given a range of years, months and weekdays

Usage

get_daily_n_sessions(sessions, years, months, wdays)

Value

tibble with the number of sessions of each date in the given time period

Arguments

sessions

tibble, sessions data set in evprof standard format.

years

vector of integers, range of years to consider

months

vector of integers, range of months to consider

wdays

vector of integers, range of weekdays to consider

Examples

Run this code
get_daily_n_sessions(
  california_ev_sessions,
  year = 2018, months = c(5, 6), wdays = 1
)

Run the code above in your browser using DataLab