powered by
Get daily number of sessions given a range of years, months and weekdays
get_daily_n_sessions(sessions, years, months, wdays)
tibble with the number of sessions of each date in the given time period
tibble, sessions data set in evprof standard format.
vector of integers, range of years to consider
vector of integers, range of months to consider
vector of integers, range of weekdays to consider
get_daily_n_sessions( california_ev_sessions, year = 2018, months = c(5, 6), wdays = 1 )
Run the code above in your browser using DataLab